@@ -103,6 +103,3 @@ FANG %>%
   mutate(rolling_lm = lm_roll(adjusted, volume, numeric_date)) %>%
   filter(!is.na(rolling_lm))
 
-## ---- echo=FALSE--------------------------------------------------------------
-knitr::include_graphics("time_series_course.jpg")
-
